% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sacoRiverModel.R
\name{sacoRiverModel}
\alias{sacoRiverModel}
\title{Saco River Model}
\usage{
sacoRiverModel(nRuns = 1, nYears = 50, timing = list(1, 1, 1, 1, 1,
  1), upstream = list(cataract = 1, spring = 1, skelton = 1, barmills =
  1, westBuxton = 1, bonnyEagle = 1), downstream = list(cataract = 1,
  spring = 1, barmills = 1, skelton = 1, westBuxton = 1, bonnyEagle = 1),
  inRiverF = 0, commercialF = 0, bycatchF = 0, indirect = 1,
  latent = 1, watershed = TRUE)
}
\arguments{
\item{nRuns}{The number of times that the
model will be run.}

\item{nYears}{The number of years for which
each run will last. The default is 50 years
to match hydropower license duration in the
Penobscot River.}

\item{timing}{The amount of time required for
upstream passage by individual fish (in days), 
where the default (1) indicates a 24-h dam
passage performance standard.}

\item{upstream}{A named list of upstream dam
passage efficiencies at each dam in the 
Saco River.

Users may specify a single value of upstream
passage at each dam, or a vector of upstream
passage efficiencies at each dam. Note that
passage efficiences passed as vectors are 
randomly sampled during each model run 
(not each year). Therefore, multiple model runs
are necessary if more than one passage efficiency
is supplied for any dam.}

\item{downstream}{A named list of downstream
dam passage efficiencies at each dam.

Users may specify a single value of downstream
passage at each dam, or a vector of downstream
passage efficiencies at each dam. Note that
passage efficiences passed as vectors are 
randomly sampled during each model run 
(not each year). Therefore, multiple model runs
are necessary if more than one passage efficiency
is supplied for any dam.}

\item{inRiverF}{Annual, recreational harvest of 
American shad. Parameterized as an annual rate [0, 1].}

\item{commercialF}{Commercial fishery mortality
for American shad in marine environment incurred 
through targeted fisheries. Parameterized as an 
annual rate [0, 1].}

\item{bycatchF}{Marine bycatch mortality of
American shad in non-target fisheries. 
Parameterized as an annual rate [0, 1].}

\item{indirect}{Indirect mortality incurred during
freshwater migration as a result of dam-related
impacts (e.g., injury, predation, etc.).}

\item{latent}{Latent mortality incurred during estuary
passage as a result of dam-related impacts (e.g., injury,
delay, etc.).}

\item{watershed}{A logical indicating whether or not
to use the same dam passage efficiencies at all dams
for upstream and downstream. If watershed = TRUE, then
the first element in lists `upstream` and `downstream`
are recycled for all subsequent dams.}
}
\value{
Returns a list of two named dataframes.
The first dataframe (\code{res}) contains user-defined
inputs and available model outputs. THe second (\code{sens})
contains stochastic variables for sensitivity analysis.

If run in parallel, returns a list of lists
of dataframes.

The folowing named columns are returned in \code{res}:
\itemize{
    \item \code{year} Year of simulation

    \item \code{time_cataract...time_bonnyEagle} Passage timing input by user

    \item \code{cataract_up...bonnyEagle_up} User-specified upstream passage efficiencies
 
    \item \code{cataract_down...bonnyEagle_down}  User-specified downstream passage efficiencies
 
    \item \code{pRepeat_Age1...Age9} Age-specific probability of repeat spawning  
 
    \item \code{populationSize} Total number of adult spawners returning to the river

    \item \code{N_I...N_VII} Production unit-specific population size after in-river fishery mortality
}

The following named columns are returned in \code{sens}:
\itemize{
    \item \code{S.downstream} Downstream survival per kilometer
    \item \code{S.marine} Marine survival (z, instantaneous)
    \item \code{popStart} Starting population size
    \item \code{p.female} Probability of being female
    \item \code{S.prespawnM} Prespawn survival rate for males
    \item \code{S.postspawnM} Postspawn survival rate for males
    \item \code{S.prespawnF} Postspawn survival rate for males
    \item \code{S.postspawnF} Postspawn survival rate for males
    \item \code{S.juvenile} Hatch to out-migrant survival rate
    \item \code{t.stoch} Temperature stochasticity parameter
    \item \code{b.Arr} Mean arrival date for males
    \item \code{r.Arr} Mean arrival date for females
    \item \code{ATUspawn1} Accumulated thermal units at initiation of spawn
    \item \code{ATUspawn2} Accumulated thermal units at termination of spawn
    \item \code{Dspawn1} Initial spawning date
    \item \code{Dspawn2} Terminal spawning date
    \item \code{linF} L-infinity parameter from the von Bertalanffy growth function for females
    \item \code{kF} K parameter from the von Bertalanffy growth function for females
    \item \code{t0F} t0 parameter from the von Bertalanffy growth function for females
    \item \code{linM} L-infinity parameter from the von Bertalanffy growth function for males
    \item \code{kM} K parameter from the von Bertalanffy growth function for males
    \item \code{t0M} t0 parameter from the von Bertalanffy growth function for males
    \item \code{b.length} Mean length of males
    \item \code{r.length} Mean length of females
    \item \code{spawnInt} Mean spawning interval
    \item \code{batchSize} Mean batch size
    \item \code{resTime} Mean residence time
    \item \code{s.Optim} Mean optimal ground speed
    \item \code{d.Max} Mean maximum daily movement rate
    \item \code{tortuosity} Path tortuosity parameter
    \item \code{motivation} Seasonal change in fish "motivation" for upstream movement
    \item \code{daily.move} Mean realized daily movement rate
    \item \code{habStoch} Habitat stochasticity
}
}
\description{
Runs American shad dam passage performance
standard model for Saco River, Maine,
USA
}
\section{Warning about serial execution and memory limits}{

Current implementation is based on work
in review, and is thus subject to modification 
without notice. 

Currently, internal functions rely on \code{list2env} to return
lists to a temporary environment created in the 
\code{sacoRiverModel} function. Consequently, lists 
that are exported must be limited in size. Therefore, 
users currently need to limit the number of runs per 
call (\code{nRuns} argument) to less than 10 or R will 
hit memory limits quickly. In reality, serial 
execution is prohibitively slow unless implemented 
using manual parallel processing (e.g., bash scripting).

In order to achieve a desired number of runs for a given
set of inputs, the recommended approach is to use 
parallel execution as demonstrated using snowfall in the
example below.
}

